@@ -5,23 +5,23 @@
 #' @param fit an object of the class sglg. This object is returned from the call to glg(), sglg(), survglg() or ssurvglg().
 #' @param conf_lev is the confidence level of the asymptotic confidence band. Default value is 0.05.
 #' @references Eilers P.H.C. and Marx B.D. (1996). Flexible smoothing with B-splines and penalties. Statistical Science. 11, 89-121.
-#' @references Wood, S. (2006). Additive generalized models: An R introduction. Chapman and Hall.
-#' @author Carlos Alberto Cardozo Delgado <cardozorpackages@gmail.com>, G. Paula and L. Vanegas.
+#' @references Wood, S. (2017). Additive generalized models: An R introduction. Chapman and Hall.
+#' @author Carlos Alberto Cardozo Delgado <cardozorpackages@gmail.com>
 #' @import graphics
 #' @import ggplot2
 #' @examples
 #' set.seed(1)
 #' n <- 300
-#' error <- rglg(n,0,1,1)
+#' error <- rglg(n,0,0.5,1)
 #' t <- as.matrix((2*1:n - 1)/(2*n))
 #' colnames(t) <- "t"
 #' f_t <- cos(4*pi*t)
-#' y <- 0.5 + f_t + error
+#' y <- 0.8 + f_t + error
 #' colnames(y) <- "y"
 #' data <- as.data.frame(cbind(y,1,t))
-#' fit1 <- sglg(y ~ 1,npc=t,data=data,basis = "Gu",alpha0=seq(0.001,0.005,by=0.001),nknts=9)
-#' quantile_residuals(fit1)
-#' # The adjusted (black) and true (red) non-linear component
+#' fit1 <- sglg(y ~ 1,npc=t,data=data,basis = "deBoor",alpha0=0.0001)
+#' summary(fit1)
+#' # The adjusted (black) non-linear component
 #' plotnpc(fit1,conf_lev=0.02)
 #' @export plotnpc
 
@@ -43,18 +43,23 @@ plotnpc <- function(fit,conf_lev) {
     f_est <- N[,-(1:p)]%*%mu[-(1:p)]
     if (fit$basis == "deBoor"){
         f_est <- f_est + mu[1]
-        #Knot <- fit$Knot
-        #var_gammas <- fit$scovar[(p+1):(p+Knot),(p+1):(p+Knot)]
-        #var_f_est <- N[,-(1:p)]%*%var_gammas%*%t(N[,-(1:p)])
-        #st_error_f_est <- sqrt(diag(var_f_est))
-        #f_est_low <- f_est + qnorm(0.5*conf_lev)*st_error_f_est
-        #f_est_up <- f_est + qnorm(1 - 0.5*conf_lev)*st_error_f_est
-        df <- as.data.frame(cbind(y,npc,N,f_est))
+        Knot <- fit$Knot
+        var_gammas <- fit$scovar[(p+1):(p+Knot),(p+1):(p+Knot)]
+        var_f_est <- N[,-(1:p)]%*%var_gammas%*%t(N[,-(1:p)])
+        st_error_f_est <- sqrt(diag(var_f_est))
+        f_est_low <- f_est + qnorm(0.5*conf_lev)*st_error_f_est
+        f_est_up <- f_est + qnorm(1 - 0.5*conf_lev)*st_error_f_est
+
+        df <- as.data.frame(cbind(y,N,f_est))
         plot <- ggplot(data=df,aes(npc,y))+
-            #geom_point(colour="blue",alpha=0.4)+
-            #geom_line(aes(npc,f_est_up),colour = "orange",size=1.2) +
-            geom_line(aes(npc,f_est),size=1.2) +
-            #geom_line(aes(npc,f_est_low),colour = "orange",size=1.2) +
+
+        geom_point(colour="blue",alpha=0.4)+
+        #geom_line(aes(npc,f_est_up),colour = "orange",size=1.2) +
+
+        geom_line(aes(npc,f_est),size=1.2) +
+
+        #geom_line(aes(npc,f_est_low),colour = "orange",size=1.2) +
+
             xlab(colnames(npc))+
             ggtitle(add_comp)
         return(plot)
@@ -66,7 +71,7 @@ plotnpc <- function(fit,conf_lev) {
     st_error_f_est <- sqrt(diag(var_f_est))
     f_est_low <- f_est + qnorm(0.5*conf_lev)*st_error_f_est
     f_est_up <- f_est + qnorm(1 - 0.5*conf_lev)*st_error_f_est
-    df <- as.data.frame(cbind(y,npc,N,f_est))
+    df <- as.data.frame(cbind(y,N,f_est))
     plot <- ggplot(data=df,aes(npc,y))+
     #geom_point(colour="blue",alpha=0.4)+
     geom_line(aes(npc,f_est_up),colour = "orange",size=1.2) +
